@@ -77,3 +77,26 @@ class ClientModel(ABC):
         self.validate()
         metric_units = guessMetricByType({}, self.dict)
         self.__setitem__('units', metric_units)
+
+    def calculate_total_without_base_values(self):
+        ''' calculate the total of all metrics without base values '''
+        total = 0
+        for key in self.dict.items():
+            if key == 'total':
+                continue
+            elif key == 'units':
+                continue
+            elif key == 'author':
+                continue
+            elif key == 'plugin_version':
+                continue
+            elif key == 'heartbeat_required':
+                continue
+            elif key == 'date_created':
+                continue
+            else:
+                try:
+                    total += int(self.dict[key])
+                except ValueError:
+                    pass
+        self.__setitem__('total', total)
